@@ -3,6 +3,7 @@ import pdb
 import sys
 import nose.case
 import nose.failure
+from nose.pyversion import unbound_method
 from nose.config import Config
 from mock import ResultProxyFactory, ResultProxy
 
@@ -27,7 +28,8 @@ class TestNoseCases(unittest.TestCase):
             def test_func(self, a=a):
                 a.append(1)
 
-        case = nose.case.MethodTestCase(TestClass.test_func)
+        case = nose.case.MethodTestCase(unbound_method(TestClass,
+                                                       TestClass.test_func))
         case(res)
         assert a[0] == 1
 
@@ -43,7 +45,8 @@ class TestNoseCases(unittest.TestCase):
             def test_func(self, a=a):
                 a.append(1)
 
-        case = nose.case.MethodTestCase(TestClass.test_func)
+        case = nose.case.MethodTestCase(unbound_method(TestClass,
+                                                       TestClass.test_func))
         case(res)
         assert a[0] == 1
 
@@ -58,7 +61,8 @@ class TestNoseCases(unittest.TestCase):
             def test_func(self):
                 called.append('test')
 
-        case = nose.case.MethodTestCase(TestClass.test_func)
+        case = nose.case.MethodTestCase(unbound_method(TestClass,
+                                                       TestClass.test_func))
         case(res)
         self.assertEqual(called, ['setup', 'test', 'teardown'])
 
@@ -67,7 +71,8 @@ class TestNoseCases(unittest.TestCase):
                 called.append('setup')
                 raise Exception("failed")
         called[:] = []
-        case = nose.case.MethodTestCase(TestClassFailingSetup.test_func)
+        case = nose.case.MethodTestCase(unbound_method(TestClassFailingSetup,
+                                            TestClassFailingSetup.test_func))
         case(res)
         self.assertEqual(called, ['setup'])        
 
@@ -77,7 +82,8 @@ class TestNoseCases(unittest.TestCase):
                 raise Exception("failed")
             
         called[:] = []
-        case = nose.case.MethodTestCase(TestClassFailingTest.test_func)
+        case = nose.case.MethodTestCase(unbound_method(TestClassFailingTest,
+                                            TestClassFailingTest.test_func))
         case(res)
         self.assertEqual(called, ['setup', 'test', 'teardown'])     
         
@@ -189,17 +195,21 @@ class TestNoseTestWrapper(unittest.TestCase):
             dummy, arg=(1,), descriptor=test))
         self.assertEqual(case.address(), (fl, __name__, 'test'))
 
-        case = nose.case.Test(nose.case.MethodTestCase(Test.test))
+        case = nose.case.Test(nose.case.MethodTestCase(
+                                  unbound_method(Test, Test.test)))
         self.assertEqual(case.address(), (fl, __name__, 'Test.test'))
 
         case = nose.case.Test(
-            nose.case.MethodTestCase(Test.try_something, arg=(1,2,),
-                                     descriptor=Test.test_gen))
+            nose.case.MethodTestCase(unbound_method(Test, Test.try_something),
+                                     arg=(1,2,),
+                                     descriptor=unbound_method(Test,
+                                                               Test.test_gen)))
         self.assertEqual(case.address(),
                          (fl, __name__, 'Test.test_gen'))
 
         case = nose.case.Test(
-            nose.case.MethodTestCase(Test.test_gen, test=dummy, arg=(1,)))
+            nose.case.MethodTestCase(unbound_method(Test, Test.test_gen),
+                                     test=dummy, arg=(1,)))
         self.assertEqual(case.address(),
                          (fl, __name__, 'Test.test_gen'))
 
@@ -220,7 +230,8 @@ class TestNoseTestWrapper(unittest.TestCase):
         case = nose.case.Test(nose.case.FunctionTestCase(test))
         self.assertEqual(case.context, sys.modules[__name__])
 
-        case = nose.case.Test(nose.case.MethodTestCase(Test.test))
+        case = nose.case.Test(nose.case.MethodTestCase(unbound_method(Test,
+                                                           Test.test)))
         self.assertEqual(case.context, Test)
 
     def test_short_description(self):
